import es
import cfglib

info = es.AddonInfo()
info.name = 'Custom Script Loader'
info.version = '1.1'
info.author = 'scaiyth'
info.url = 'http://addons.eventscripts.com/addons/view/csl'
info.description = "Auto loads one or more scripts + a config file on certain (predefined) maps"
info.basename = 'csl'

csl_var = es.ServerVar(info.basename, info.version, info.name + ': ' + info.description + '\n// by ' + info.author)

csl_config = cfglib.AddonCFG(es.getAddonPath(info.basename) + "/config.cfg", 1)
csl_maps = csl_config.cvar('csl_maps', '', 'Mapnames or parts of mapnames (e.g. prefixes) which trigger CSL to load the script')
csl_except_maps = csl_config.cvar('csl_except_maps', '', 'Mapnames which CSL will ignore for loading')
csl_scriptnames = csl_config.cvar('csl_scriptnames', '', 'Script name of the script that will be loaded')
csl_configfile = csl_config.cvar('csl_configfile', '', 'Name of a config file that will be executed once after loading the script(s)')
csl_auto_unload_scripts = csl_config.cvar('csl_auto_unload', 1, 'Enable/Disable unloading the script on normal maps')

def load():
	csl_var.set(info.version)
	csl_var.makepublic()
	csl_config.execute()

def es_map_start(event_var):
	script_loadconfig = 0
	script_cslmap = script_map_check(event_var['mapname'])
	for script_scriptname in str(csl_scriptnames).replace(" ", "").split(","):
		script_loaded = script_loaded_check(script_scriptname)
		if not script_loaded and script_cslmap:
			es.delayed('1', 'es_load %s' % script_scriptname)
			script_loadconfig = 1
		elif script_loaded:
			if csl_auto_unload_scripts == 1 and not script_cslmap:
				es.unload(script_scriptname)
				es.delayed('2', 'exec server.cfg')
	else:
		if script_loadconfig and csl_configfile != "": es.delayed('1.5', 'exec "%s"' % csl_configfile)

def script_loaded_check(script):
	if script != "":
		if es.exists('script', script):
			return 1
		else:
			for scriptname in es.addons.getAddonList():
				scriptstring = str(scriptname.__name__)
				if scriptstring == script + '.' + script:
					return 1
	return 0

def script_map_check(map = es.ServerVar('eventscripts_currentmap')):
	map = str(map).lower()
	if map != "":
		for script_except_map in str(csl_except_maps).replace(" ,", ",").replace(", ", ",").split(","):
			if script_except_map.lower() == map:
				return 0
		else:
			for mapstring in str(csl_maps).replace(" ", "").split(","):
				if mapstring.lower() in map and mapstring != "":
					return 1
			else:
				return 0
	else:
		return 0
